@@ -12,14 +12,20 @@ my $gh_xs = Geo::Hash::XS->new();
 print "Geo::Hash: $Geo::Hash::VERSION\n",
     "Geo::Hash::XS: $Geo::Hash::XS::VERSION\n\n";
 
-for my $p (5, 10, 20, 30) {
-    print STDERR "precision = $p...\n";
+for my $p (0, 5, 10, 20, 30) {
+    my @args = ($lat, $lon);
+    if ($p != 0) {
+        push @args, $p;
+        print STDERR "precision = $p...\n";
+    } else {
+        print STDERR "precision = auto...\n";
+    }
     cmpthese( -2, {
         perl => sub {
-            my $hash = $gh_pp->encode( $lat, $lon, $p );
+            my $hash = $gh_pp->encode( @args );
         },
         xs => sub {
-            my $hash = $gh_xs->encode( $lat, $lon, $p );
+            my $hash = $gh_xs->encode( @args );
         }
     });
     print "\n\n";
